@@ -18,7 +18,6 @@
  */
 package edu.berkeley.boinc.rpc
 
-import android.util.Log
 import android.util.Xml
 import edu.berkeley.boinc.utils.Logging
 import org.xml.sax.Attributes
@@ -109,7 +108,7 @@ class ProjectConfigReplyParser : BaseParser() {
             }
             mElementStarted = false
         } catch (e: Exception) {
-            Log.e(Logging.TAG, "ProjectConfigReplyParser.endElement error: ", e)
+            Logging.logException(Logging.Category.XML, "ProjectConfigReplyParser.endElement error: ", e)
         }
     }
 
@@ -135,8 +134,8 @@ class ProjectConfigReplyParser : BaseParser() {
                 Xml.parse(rpcResult.replace("<?xml version=\"1.0\" encoding=\"ISO-8859-1\" ?>", ""), parser)
                 parser.projectConfig
             } catch (e: SAXException) {
-                Log.e(Logging.TAG, "ProjectConfigReplyParser: malformed XML ", e)
-                Log.d(Logging.TAG, "ProjectConfigReplyParser: $rpcResult")
+                Logging.logException(Logging.Category.RPC, "ProjectConfigReplyParser: malformed XML ", e)
+                Logging.logDebug(Logging.Category.XML, "ProjectConfigReplyParser: $rpcResult")
 
                 null
             }
