@@ -52,6 +52,12 @@ static int CheckNestedDirectories(
     int len
 );
 
+static int CheckPodmanDirContents(
+    char * basepath,
+    char * path_to_error,
+    int len
+);
+
 #if (! defined(__WXMAC__) && ! defined(_MAC_INSTALLER))
 #include "sandbox.h"
 
@@ -73,7 +79,8 @@ static uid_t        boinc_master_uid, boinc_project_uid;
 
 // Called from BOINC Manager, BOINC Client and Installer.
 
-// Returns FALSE (0) if owners and permissions are OK, else TRUE (1)
+// Returns noErr (0) if owners and permissions are OK, else a custom error code
+//TODO: resolve symbolic links and check their ownership and permissions
 int check_security(
 #ifdef _MAC_INSTALLER
 char *bundlePath, char *dataPath,   // These arguments are used only when called from the Installer
@@ -168,45 +175,74 @@ int use_sandbox, int isManager, char* path_to_error, int len
 
 #ifdef __APPLE__
     char DataDirPath[MAXPATHLEN];
+
 #ifdef _MAC_INSTALLER
     strlcpy(DataDirPath, dataPath, sizeof(dir_path));  // Installer
 #else
     getcwd(DataDirPath, sizeof(DataDirPath));
 #endif
-    snprintf(full_path, sizeof(full_path),
-        "%s/%s", DataDirPath, FIX_BOINC_USERS_FILENAME
-    );
-    retval = stat(full_path, &sbuf);
-    if (retval)
-    return -1061;
+    if (use_sandbox) {
+       snprintf(full_path, sizeof(full_path),
+            "%s/%s", DataDirPath, FIX_BOINC_USERS_FILENAME
+        );
+        retval = stat(full_path, &sbuf);
+        if (retval)
+            return -1061;
 
-    if (sbuf.st_uid != 0)   // root
-         return -1062;
+        if (sbuf.st_uid != 0)   // root
+             return -1062;
 
-    if (sbuf.st_gid != boinc_master_gid)
-        return -1063;
+        if (sbuf.st_gid != boinc_master_gid)
+            return -1063;
 
-    if ((sbuf.st_mode & 07777) != 04555)
-        return -1064;
+        if ((sbuf.st_mode & 07777) != 04555)
+            return -1064;
 
-    if (! isMacInstaller) {
-    // MacOS updates often change the PrimaryGroupID of boinc_master and
-    // boinc_project to 20 (staff.)
-        if ((retval2 == -1301) || (retval2 == -1302)) {
-            snprintf(full_path, sizeof(full_path),
-                "\"%s/%s\"", DataDirPath, FIX_BOINC_USERS_FILENAME
-            );
-            printf("Permissions error %d, calling %s\n", retval2, full_path);
-            callPosixSpawn(full_path);  // Try to fix it
-            retval2 = check_boinc_users_primarygroupIds(useFakeProjectUserAndGroup, isMacInstaller);
+        if (! isMacInstaller) {
+        // MacOS updates often change the PrimaryGroupID of boinc_master and
+        // boinc_project to 20 (staff.)
+            if ((retval2 == -1301) || (retval2 == -1302)) {
+                snprintf(full_path, sizeof(full_path),
+                    "\"%s/%s\"", DataDirPath, FIX_BOINC_USERS_FILENAME
+                );
+                printf("Permissions error %d, calling %s\n", retval2, full_path);
+                callPosixSpawn(full_path);  // Try to fix it
+                retval2 = check_boinc_users_primarygroupIds(useFakeProjectUserAndGroup, isMacInstaller);
+            }
         }
-    }
-    if (retval2)
-        return retval2;
+        if (retval2)
+            return retval2;
+
+        snprintf(full_path, sizeof(full_path),
+            "%s/%s", DataDirPath, RUN_PODMAN_FILENAME
+        );
+        retval = stat(full_path, &sbuf);
+        if (retval)
+            return -1065;
+
+        if (sbuf.st_gid != boinc_master_gid)
+            return -1066;
+
+        if (sbuf.st_uid != 0)   // root
+            return -1067;
+
+        if ((sbuf.st_mode & 07777) != 04555)
+            return -1068;
+#if 0
+    } else {
+        if (sbuf.st_uid != boinc_master_uid)
+            return -1067;
+
+        if ((sbuf.st_mode & 07777) != 0755)
+            return -1068;
 #endif
+    }   // use_sandbox
+
+#endif  // __APPLE__
 
 #if 0   // Manager is no longer setgid
 #if (defined(__WXMAC__) || defined(_MAC_INSTALLER)) // If Mac BOINC Manager or installer
+    if (use_sandbox) {
         // Get the full path to BOINC Manager executable
         // inside this application's bundle
         //
@@ -234,24 +270,35 @@ int use_sandbox, int isManager, char* path_to_error, int len
             if ((sbuf.st_mode & S_ISGID) != S_ISGID)
                 return -1015;
         }
+    }   // use_sandbox
 #endif
 #endif   // Manager is no longer setgid
 
 
 #if (defined(__WXMAC__) || defined(_MAC_INSTALLER)) // If Mac BOINC Manager or installer
-        // Require absolute owner and group boinc_master:boinc_master
-        // Get the full path to BOINC Client inside this application's bundle
-        //
-        retval = stat("/Applications/BOINCManager.app/Contents/Resources/boinc", &sbuf);
-        if (retval)
-            return -1016;          // Should never happen
+    if (use_sandbox) {
+            // Require absolute owner and group boinc_master:boinc_master
+            // Get the full path to BOINC Client inside this application's bundle
+            //
+        long brandId = 0;
+        FILE *f = fopen("/Library/Application Support/BOINC Data/Branding", "r");
+        if (f) {
+            fscanf(f, "BrandId=%ld\n", &brandId);
+            fclose(f);
+        }
 
-        if (sbuf.st_gid != boinc_master_gid)
-            return -1017;
+        snprintf(full_path, sizeof(full_path),"/%s/Contents/Resources/boinc", appPath[brandId]);
+            retval = stat(full_path, &sbuf);
+            if (retval)
+                return -1016;          // Should never happen
 
-        if (sbuf.st_uid != boinc_master_uid)
-            return -1018;
-#endif
+            if (sbuf.st_gid != boinc_master_gid)
+                return -1017;
+
+            if (sbuf.st_uid != boinc_master_uid)
+                return -1018;
+    }
+#endif  // use_sandbox
 
 #if (defined(__WXMAC__) || defined(_MAC_INSTALLER)) // If Mac BOINC Manager or installer
         // Version 6 screensaver has its own embedded switcher application, but older versions don't.
@@ -316,23 +363,20 @@ int use_sandbox, int isManager, char* path_to_error, int len
         return -1021;          // Should never happen
 
     if (use_sandbox) {
-
         // The top-level BOINC Data directory can have a different user if created by the Manager,
         // but it should always have group boinc_master.
         if (sbuf.st_gid != boinc_master_gid)
             return -1022;
 
         // The top-level BOINC Data directory should have permission 771 or 571
-        if ((sbuf.st_mode & 0577) != 0571)
+        if ((sbuf.st_mode & 07577) != 0575)
             return -1023;
-
+#if 0
     } else {
-
         if (sbuf.st_uid != boinc_master_uid)
             return -1022;
-
+#endif
     }
-
     snprintf(full_path, sizeof(full_path), "%s/%s", dir_path, PROJECTS_DIR);
     retval = stat(full_path, &sbuf);
     if (!retval) {
@@ -342,13 +386,12 @@ int use_sandbox, int isManager, char* path_to_error, int len
             if (sbuf.st_gid != boinc_project_gid)
                 return -1024;
 
-        if ((sbuf.st_mode & 0777) != 0770)
-            return -1025;
+            if ((sbuf.st_mode & 07777) != 0770)
+                return -1025;
+
+            if (sbuf.st_uid != boinc_master_uid)
+                return -1026;
         }
-
-        if (sbuf.st_uid != boinc_master_uid)
-            return -1026;
-
         // Step through project directories
         retval = CheckNestedDirectories(full_path, 1, use_sandbox, isManager, false, path_to_error, len);
         if (retval)
@@ -362,12 +405,12 @@ int use_sandbox, int isManager, char* path_to_error, int len
             if (sbuf.st_gid != boinc_project_gid)
                 return -1027;
 
-            if ((sbuf.st_mode & 0777) != 0770)
+            if ((sbuf.st_mode & 07777) != 0770)
                 return -1028;
-        }
 
-        if (sbuf.st_uid != boinc_master_uid)
-            return -1029;
+            if (sbuf.st_uid != boinc_master_uid)
+                return -1029;
+        }
 
         // Step through slot directories
         retval = CheckNestedDirectories(full_path, 1, use_sandbox, isManager, true, path_to_error, len);
@@ -375,22 +418,27 @@ int use_sandbox, int isManager, char* path_to_error, int len
             return retval;
     }
 
-    snprintf(full_path, sizeof(full_path), "%s/%s", dir_path, PODMAN_DIR);
-    retval = stat(full_path, &sbuf);
-    if (! retval) {                 // Client can create podman directory if it does not yet exist.
-       if (use_sandbox) {
-            if (sbuf.st_gid != boinc_project_gid)
-                return -1071;
+    if (use_sandbox) {
+        // "BOINC Podman" Directory is in "/Library/Application/Support/"
+        // directory, alongside "BOINC Data" directory
+        snprintf(full_path, sizeof(full_path), "%s/../%s", dir_path, PODMAN_DIR);
+        retval = stat(full_path, &sbuf);
+        if (retval)
+            return -1071;
 
-            if ((sbuf.st_mode & 0777) != 0770)
-                return -1072;
-        }
+        if (sbuf.st_gid != boinc_project_gid)
+            return -1072;
 
-        if (sbuf.st_uid != boinc_master_uid)
+        if ((sbuf.st_mode & 07777) != 0770)
             return -1073;
 
-        // Step through slot directories
-        retval = CheckNestedDirectories(full_path, 1, use_sandbox, isManager, false, path_to_error, len);
+        if (sbuf.st_uid != boinc_master_uid)
+            return -1074;
+
+        // We must not modify permissions of any of Podman's data,
+        // so we set them for the BOINC podman directory itself
+        // but not its contents.
+        retval = CheckPodmanDirContents(full_path, path_to_error, len);
         if (retval)
             return retval;
     }
@@ -404,15 +452,15 @@ int use_sandbox, int isManager, char* path_to_error, int len
             if (sbuf.st_gid != boinc_master_gid)
                 return -1030;
 
-            if ((sbuf.st_mode & 0777) != 0660)
+            if ((sbuf.st_mode & 07777) != 0660)
                 return -1032;
+
+            if (sbuf.st_uid != boinc_master_uid)
+                return -1031;
         } else {
-            if ((sbuf.st_mode & 0717) != 0600)
+            if ((sbuf.st_mode & 07717) != 0600)
                 return -1032;
         }
-
-        if (sbuf.st_uid != boinc_master_uid)
-            return -1031;
     }
 
     if (use_sandbox) {
@@ -427,7 +475,7 @@ int use_sandbox, int isManager, char* path_to_error, int len
         if (sbuf.st_uid != boinc_master_uid)
             return -1035;
 
-        if ((sbuf.st_mode & 0777) != 0550)
+        if ((sbuf.st_mode & 07777) != 0550)
             return -1036;
 
         strlcat(full_path, "/", sizeof(full_path));
@@ -492,7 +540,7 @@ int use_sandbox, int isManager, char* path_to_error, int len
             if (sbuf.st_gid != boinc_master_gid)
                 return -1052;
 
-            if ((sbuf.st_mode & 0777) != 0664)
+            if ((sbuf.st_mode & 07777) != 0664)
                 return -1053;
         }   // Screensaver config file ss_config.xml exists
 
@@ -583,6 +631,8 @@ static int CheckNestedDirectories(
     dirent          *dp;
     static int      errShown = 0;
 
+    if (!use_sandbox) return 0;
+
     dirp = opendir(basepath);
     if (dirp == NULL) {
         // Ideally, all project-created subdirectories under project or slot
@@ -665,14 +715,14 @@ static int CheckNestedDirectories(
                     if (depth == 1) {
                     // project & slot directories (projects/setiathome.berkeley.edu, slots/0 etc.)
                     // must be readable & executable by other
-                        if ((sbuf.st_mode & 0777) != 0775) {
+                        if ((sbuf.st_mode & 07777) != 0775) {
                             retval = -1203;
                             break;
                         }
 #if 0               // We may enforce permissions later for subdirectories written by project applications
                     } else {
                         // subdirectories created by projects may be executable by other or not
-                        if ((sbuf.st_mode & 0770) != 0770) {
+                        if ((sbuf.st_mode & 07777) != 0770) {
                             retval = -1203;
                             break;
                         }
@@ -680,7 +730,7 @@ static int CheckNestedDirectories(
                 }
 #if 0           // We may enforce permissions later for files written by project applications
                 } else {    // ! isDirectory
-                    if ((sbuf.st_mode & 0666) != 0660) {
+                    if ((sbuf.st_mode & 07666) != 0660) {
                         retval = -1204;
                         break;
                     }
@@ -702,7 +752,7 @@ static int CheckNestedDirectories(
                 break;
         }
 
-    }       // End while (true)
+    }       // End while (dirp)
 
     if (dirp) {
         closedir(dirp);
@@ -719,6 +769,80 @@ static int CheckNestedDirectories(
 }
 
 
+static int CheckPodmanDirContents(
+    char * basepath,
+    char * path_to_error,
+    int len
+) {
+    int             isDirectory;
+    char            full_path[MAXPATHLEN];
+    struct stat     sbuf;
+    int             retval = 0;
+    DIR             *dirp;
+    dirent          *dp;
+    static int      errShown2 = 0;
+
+    dirp = opendir(basepath);
+    if (dirp == NULL) {
+        // Ideally, all project-created subdirectories under project or slot
+        // directoriesshould have read-by-group and execute-by-group permission
+        // bits set, but some don't.  If these permission bits are missing, the
+        // project applications will run OK but we can't access the contents of
+        // the subdirectory to check them.
+        strlcpy(full_path, basepath, sizeof(full_path));
+        if (errno == EACCES) {
+            return 0;
+        }
+    }
+
+    while (dirp) {              // Skip this if dirp == NULL, else loop until break
+        dp = readdir(dirp);
+        if (dp == NULL)
+            break;                  // End of list
+
+        if (dp->d_name[0] == '.')
+            continue;               // Ignore names beginning with '.'
+
+        snprintf(full_path, sizeof(full_path), "%s/%s", basepath, dp->d_name);
+        retval = lstat(full_path, &sbuf);
+        if (retval)
+            break;              // Should never happen
+
+        isDirectory = S_ISDIR(sbuf.st_mode);
+        if (!S_ISLNK(sbuf.st_mode)) {   // The system ignores ownership & permissions of symbolic links
+            if ( sbuf.st_uid != boinc_project_uid) {
+                retval = -1075;
+                break;
+            }
+
+            if (sbuf.st_gid != boinc_project_gid) {
+                retval = -1076;
+                break;
+            }
+
+            if (isDirectory && !S_ISLNK(sbuf.st_mode)) {
+                retval = CheckPodmanDirContents(full_path, path_to_error, len);
+                if (retval)
+                    break;
+            }
+        }
+    }       // End while (dirp)
+
+    if (dirp) {
+        closedir(dirp);
+    }
+
+    if (retval && !errShown2) {
+        fprintf(stderr, "Permissions error %d at %s\n", retval, full_path);
+        if (path_to_error) {
+            strlcpy(path_to_error, full_path, len);
+        }
+        errShown2 = 1;
+    }
+    return retval;
+}
+
+
 #if (! defined(__WXMAC__) && ! defined(_MAC_INSTALLER))
 
 static char * PersistentFGets(char *buf, size_t buflen, FILE *f) {
