@@ -78,6 +78,7 @@ extern void send_log_after(const char* filename, double t, MIOFILE& mf);
 #define CREATE_ACCOUNT_FILENAME     "create_account.xml"
 #define DAILY_XFER_HISTORY_FILENAME "daily_xfer_history.xml"
 #define FIX_BOINC_USERS_FILENAME    "Fix_BOINC_Users"
+#define RUN_PODMAN_FILENAME         "Run_Podman"
 #define GET_CURRENT_VERSION_FILENAME    "get_current_version.xml"
 #define GET_PROJECT_CONFIG_FILENAME "get_project_config.xml"
 #define GLOBAL_PREFS_FILE_NAME      "global_prefs.xml"
@@ -89,7 +90,11 @@ extern void send_log_after(const char* filename, double t, MIOFILE& mf);
 #define LOOKUP_WEBSITE_FILENAME     "lookup_website.html"
 #define MASTER_BASE                 "master_"
 #define NOTICES_DIR                 "notices"
+#ifdef __APPLE__
+#define PODMAN_DIR                  "BOINC podman"
+#else
 #define PODMAN_DIR                  "podman"
+#endif
 #define PROJECTS_DIR                "projects"
 #define REMOTEHOST_FILE_NAME        "remote_hosts.cfg"
 #define SCHED_OP_REPLY_BASE         "sched_reply_"
