@@ -1411,12 +1411,15 @@ static void handle_run_graphics_app(GUI_RPC_CONN& grc) {
     string theScreensaverLoginUser;
     char screensaverLoginUser[256];
     char switcher_path[MAXPATHLEN];
+    char gfx_switcher_path[MAXPATHLEN];
     char *execName, *execPath;
     char current_dir[MAXPATHLEN];
     char *execDir;
     int newPID = 0;
     ACTIVE_TASK* atp = NULL;
     char cmd[256];
+    bool need_to_launch_gfx_ss_bridge = false;
+    static int gfx_ss_bridge_pid = 0;
 
     while (!grc.xp.get_tag()) {
         if (grc.xp.match_tag("/run_graphics_app")) break;
@@ -1498,6 +1501,36 @@ static void handle_run_graphics_app(GUI_RPC_CONN& grc) {
         return;
     }
 
+    // As of MacOS 14.0, the legacyScreenSaver sandbox prevents using
+    // bootstrap_look_up, so we launch a bridging utility to relay Mach
+    // communications between the graphics apps and the legacyScreenSaver.
+    if (gfx_ss_bridge_pid == 0) {
+        need_to_launch_gfx_ss_bridge = true;
+    } else if (waitpid(gfx_ss_bridge_pid, 0, WNOHANG)) {
+        gfx_ss_bridge_pid = 0;
+        need_to_launch_gfx_ss_bridge = true;
+    }
+    if (need_to_launch_gfx_ss_bridge) {
+        if (g_use_sandbox) {
+
+            snprintf(gfx_switcher_path, sizeof(gfx_switcher_path),
+                "/Library/Screen Savers/%s.saver/Contents/Resources/gfx_switcher",
+                saverName[iBrandID]
+            );
+        }
+        argv[0] = const_cast<char*>("gfx_switcher");
+        argv[1] = "-run_bridge";
+        argv[2] = gfx_switcher_path;
+        argc = 3;
+        if (!theScreensaverLoginUser.empty()) {
+            argv[argc++] = "--ScreensaverLoginUser";
+            safe_strcpy(screensaverLoginUser, theScreensaverLoginUser.c_str());
+            argv[argc++] = screensaverLoginUser;
+        }
+        argv[argc] = 0;
+        retval = run_program(current_dir, gfx_switcher_path, argc, argv, gfx_ss_bridge_pid);
+    }
+
     if (slot == -1) {
         // start boincscr
         //
@@ -1667,6 +1700,7 @@ static void handle_set_language(GUI_RPC_CONN& grc) {
     grc.mfout.printf("<error>no language found</error>\n");
 }
 
+#ifdef ANDROID
 static void handle_report_device_status(GUI_RPC_CONN& grc) {
     DEVICE_STATUS d;
     while (!grc.xp.get_tag()) {
@@ -1732,6 +1766,8 @@ int DEVICE_STATUS::parse(XML_PARSER& xp) {
     return ERR_XML_PARSE;
 }
 
+#endif      // ANDROID
+
 // Some of the RPCs have empty-element request messages.
 // We accept both <foo/> and <foo></foo>
 //
@@ -1816,7 +1852,9 @@ GUI_RPC gui_rpcs[] = {
     GUI_RPC("read_cc_config", handle_read_cc_config,                true,   false,  false),
     GUI_RPC("read_global_prefs_override", handle_read_global_prefs_override,
                                                                     true,   false,  false),
+#ifdef ANDROID
     GUI_RPC("report_device_status", handle_report_device_status,    true,   false,  false),
+#endif
     GUI_RPC("reset_host_info", handle_reset_host_info,              true,   false,  false),
     GUI_RPC("resume_result", handle_resume_result,                  true,   false,  false),
     GUI_RPC("run_benchmarks", handle_run_benchmarks,                true,   false,  false),
