@@ -127,6 +127,17 @@ int get_all_distros(WSL_DISTROS& distros) {
 
     RegCloseKey(hKey);
 
+    // if boinc-buda-runner is present, ignore others
+    //
+    for (WSL_DISTRO &wd: distros.distros) {
+        if (wd.distro_name == BOINC_WSL_DISTRO_NAME) {
+            WSL_DISTRO distro = wd;
+            distros.distros.clear();
+            distros.distros.push_back(distro);
+            break;
+        }
+    }
+
     return 0;
 }
 
@@ -442,9 +453,10 @@ void show_wsl_messages() {
             url
         );
     } else if (bdv < gstate.latest_boinc_buda_runner_version) {
+        const char *url2 = "https://github.com/BOINC/boinc/wiki/Updating-the-BOINC-WSL-distro";
         msg_printf_notice(0, true, url,
             "A new version of the BOINC WSL distro is available.  <a href=%s>Learn how to upgrade.</a>",
-            url
+            url2
         );
     }
 }
