@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2023 University of California
+// Copyright (C) 2025 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -152,18 +152,11 @@ public:
     virtual wxString        OnListGetItemText( long item, long column ) const;
     virtual wxListItemAttr* OnListGetItemAttr( long item ) const;
 
-    bool                    OnSaveState(wxConfigBase* pConfig);
-    bool                    OnRestoreState(wxConfigBase* pConfig);
-
     void                    UpdateButtons();
 
 private:
 ////@begin CDlgEventLog member variables
 ////@end CDlgEventLog member variables
-    wxTimer*                m_pRefreshTimer;
-
-    wxInt32                 m_iPreviousDocCount;
-
     CDlgEventLogListCtrl*   m_pList;
     wxArrayInt              m_iFilteredIndexes;
     wxInt32                 m_iTotalDocCount;
@@ -198,8 +191,6 @@ private:
     void                    OnSize(wxSizeEvent& event);
     void                    OnMove(wxMoveEvent& event);
 
-    void                    OnMouseUp(wxMouseEvent& event);
-
     void                    ResetMessageFiltering();
 
     void                    FindErrorMessages(bool isFiltered);
