@@ -1,6 +1,6 @@
 // This file is part of BOINC.
-// http://boinc.berkeley.edu
-// Copyright (C) 2023 University of California
+// https://boinc.berkeley.edu
+// Copyright (C) 2025 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -65,7 +65,6 @@ CSimpleProjectPanel::CSimpleProjectPanel() {
 CSimpleProjectPanel::CSimpleProjectPanel( wxWindow* parent ) :
     CSimplePanelBase( parent )
 {
-    wxSize sz;
     wxString str = wxEmptyString;
     wxWindowDC dc(this);
 
