@@ -27,7 +27,7 @@ if ($user) {
     check_tokens($user->authenticator);
     clear_cookie('auth');
     $g_logged_in_user = null;
-    header("Location: $master_url");
+    header(sprintf('Location: %s', master_url()));
     page_head("Logged out");
     echo "You are now logged out";
     page_tail();
