@@ -21,21 +21,44 @@
 //
 // A 'remote app' is one where jobs are submitted remotely:
 // - via web RPCs
-// - (and possibly also) via forms on the project web site
+// - via forms on the project web site
 //
 // In both cases only users with permission can submit; either
 // - a user_submit record with submit_all set
 // - a user_submit_app record
 //
-// They are apps are described in $remote_apps in project.inc
+// These apps are described in $remote_apps in project.inc
 //
-// This page has several functions:
-// - links to app-specific job-submission pages
-// - Admin (if privileged user)
-// - manage batches
-//      view status, get output files, abort, retire
-//   (this also shows batches created on the server)
-// - set 'use only my computers'
+// This page provides several functions involving remote apps
+// ('me' means logged-in user)
+//
+//  show_all_batches
+//      show list of batches visible to me, possibly filtered by
+//          submitting user
+//          app
+//          state (in progress, completed etc.)
+//  show_user_batches
+//      show my batches
+//  show_batches_admin_app
+//      show all batches for a given app to admin
+//  admin_all
+//      show all batches to admin
+//  batch_stats
+//      show WSS, disk usage stats for a batch
+//  query_batch
+//      show list of jobs in a batch
+//  query_job
+//      show job details and instances
+//  retire_batch
+//      retire a batch
+//  retire_multi
+//      retire multiple batches
+//  abort_batch
+//      abort a batch
+//  admin
+//      show index of admin functions
+//  update_only_own
+//      control whether my jobs should run only on my computers
 
 require_once("../inc/submit_db.inc");
 require_once("../inc/util.inc");
@@ -53,7 +76,54 @@ display_errors();
 define("PAGE_SIZE", 20);
 
 function return_link() {
-    echo "<p><a href=submit.php?action=status>Return to batches page</a>\n";
+    echo "<p><a href=submit.php?action=show_user_batches>Return to batches page</a>\n";
+}
+
+// return subset of batches in given state
+//
+function batches_in_state($all_batches, $state) {
+    $batches = [];
+    foreach ($all_batches as $batch) {
+        if ($batch->state != $state) continue;
+        $batches[] = $batch;
+    }
+    return $batches;
+}
+
+function sort_batches(&$batches, $order) {
+    switch ($order) {
+    case 'sub_asc':
+        $f = function($a, $b) {
+            return (int)($a->create_time - $b->create_time);
+        };
+        break;
+    case 'sub_desc':
+        $f = function($a, $b) {
+            return (int)($b->create_time - $a->create_time);
+        };
+        break;
+    case 'comp_asc':
+        $f = function($a, $b) {
+            return (int)($a->completion_time - $b->completion_time);
+        };
+        break;
+    case 'comp_desc':
+        $f = function($a, $b) {
+            return (int)($b->completion_time - $a->completion_time);
+        };
+        break;
+    }
+    usort($batches, $f);
+}
+
+// in progress batches don't have completion time
+//
+function in_progress_order($order) {
+    switch ($order) {
+    case 'comp_asc': return 'sub_asc';
+    case 'comp_desc': return 'sub_desc';
+    }
+    return $order;
 }
 
 // show order options
@@ -80,39 +150,12 @@ function order_item($url, $cur_order, $order, $label) {
     }
 }
 
-function order_clause($order) {
-    switch ($order) {
-    case 'sub_asc': return 'id';
-    case 'sub_desc': return 'id desc';
-    case 'comp_asc': return 'completion_time';
-    case 'comp_desc': return 'completion_time desc';
-    }
-}
-
 function get_order() {
     $order = get_str('order', true);
     if (!$order) $order = 'sub_desc';
     return $order;
 }
 
-// get params of in-progress batches; they might not be in progress anymore.
-//
-function get_batches_params($batches) {
-    $b = [];
-    foreach ($batches as $batch) {
-        if ($batch->state == BATCH_STATE_IN_PROGRESS) {
-            $wus = BoincWorkunit::enum_fields(
-                'id, name, rsc_fpops_est, canonical_credit, canonical_resultid, error_mask',
-                "batch = $batch->id"
-            );
-            $b[] = get_batch_params($batch, $wus);
-        } else {
-            $b[] = $batch;
-        }
-    }
-    return $b;
-}
-
 function state_count($batches, $state) {
     $n = 0;
     foreach ($batches as $batch) {
@@ -121,7 +164,7 @@ function state_count($batches, $state) {
     return $n;
 }
 
-function show_all_link($batches, $state, $limit, $user, $app) {
+function show_all_batches_link($batches, $state, $limit, $user, $app) {
     $n = state_count($batches, $state);
     if ($n > $limit) {
         if ($user) $userid = $user->id;
@@ -130,7 +173,7 @@ function show_all_link($batches, $state, $limit, $user, $app) {
         else $appid = 0;
 
         echo "Showing the most recent $limit of $n batches.
-            <a href=submit.php?action=show_all&state=$state&userid=$userid&appid=$appid>Show all $n</a>
+            <a href=submit.php?action=show_all_batches&state=$state&userid=$userid&appid=$appid>Show all $n</a>
             <p>
         ";
     }
@@ -138,23 +181,19 @@ function show_all_link($batches, $state, $limit, $user, $app) {
 
 // show in-progress batches.
 //
-function show_in_progress($all_batches, $limit, $user, $app) {
-    $batches = [];
-    foreach ($all_batches as $batch) {
-        if ($batch->state != BATCH_STATE_IN_PROGRESS) continue;
-        $batches[] = $batch;
-    }
+function show_in_progress($all_batches, $order, $limit, $user, $app) {
+    $batches = batches_in_state($all_batches, BATCH_STATE_IN_PROGRESS);
+    sort_batches($batches, in_progress_order($order));
     echo sprintf('<h3>Batches in progress (%d)</h3>', count($batches));
     $first = true;
     $n = 0;
     foreach ($batches as $batch) {
-        if ($batch->state != BATCH_STATE_IN_PROGRESS) continue;
         if ($limit && $n == $limit) break;
         $n++;
         if ($first) {
             $first = false;
             if ($limit) {
-                show_all_link(
+                show_all_batches_link(
                     $batches, BATCH_STATE_IN_PROGRESS, $limit, $user, $app
                 );
             }
@@ -168,8 +207,7 @@ function show_in_progress($all_batches, $limit, $user, $app) {
                 "App",
                 "# jobs",
                 "Progress",
-                "Submitted",
-                //"Logical end time<br><small>Determines priority</small>"
+                "Submitted"
             ];
             row_heading_array($x);
         }
@@ -181,8 +219,7 @@ function show_in_progress($all_batches, $limit, $user, $app) {
             $batch->app_name,
             $batch->njobs,
             "$pct_done%",
-            local_time_str($batch->create_time),
-            //local_time_str($batch->logical_end_time)
+            local_time_str($batch->create_time)
         ];
         row_array($x);
     }
@@ -194,12 +231,9 @@ function show_in_progress($all_batches, $limit, $user, $app) {
     }
 }
 
-function show_complete($all_batches, $limit, $user, $app) {
-    $batches = [];
-    foreach ($all_batches as $batch) {
-        if ($batch->state != BATCH_STATE_COMPLETE) continue;
-        $batches[] = $batch;
-    }
+function show_complete($all_batches, $order, $limit, $user, $app) {
+    $batches = batches_in_state($all_batches, BATCH_STATE_COMPLETE);
+    sort_batches($batches, $order);
     echo sprintf('<h3>Completed batches (%d)</h3>', count($batches));
     $first = true;
     $n = 0;
@@ -209,7 +243,7 @@ function show_complete($all_batches, $limit, $user, $app) {
         if ($first) {
             $first = false;
             if ($limit) {
-                show_all_link($batches, BATCH_STATE_COMPLETE, $limit, $user, $app);
+                show_all_batches_link($batches, BATCH_STATE_COMPLETE, $limit, $user, $app);
             }
             form_start('submit.php', 'get');
             form_input_hidden('action', 'retire_multi');
@@ -238,13 +272,10 @@ function show_complete($all_batches, $limit, $user, $app) {
     }
 }
 
-function show_aborted($all_batches, $limit, $user, $app) {
-    $batches = [];
-    foreach ($all_batches as $batch) {
-        if ($batch->state != BATCH_STATE_ABORTED) continue;
-        $batches[] = $batch;
-    }
+function show_aborted($all_batches, $order, $limit, $user, $app) {
+    $batches = batches_in_state($all_batches, BATCH_STATE_ABORTED);
     if (!$batches) return;
+    sort_batches($batches, $order);
     echo sprintf('<h3>Aborted batches (%d)</h3>', count($batches));
     $first = true;
     $n = 0;
@@ -254,11 +285,12 @@ function show_aborted($all_batches, $limit, $user, $app) {
         if ($first) {
             $first = false;
             if ($limit) {
-                show_all_link($batches, BATCH_STATE_ABORTED, $limit, $user, $app);
+                show_all_batches_link($batches, BATCH_STATE_ABORTED, $limit, $user, $app);
             }
-            form_start('');
+            form_start('submit.php', 'get');
+            form_input_hidden('action', 'retire_multi');
             start_table();
-            table_header("Name", "ID", "User", "App", "# Jobs", "Submitted", "Aborted");
+            table_header("Name", "ID", "User", "App", "# Jobs", "Submitted", "Aborted", 'Select');
         }
         table_row(
             "<a href=submit.php?action=query_batch&batch_id=$batch->id>$batch->name</a>",
@@ -267,21 +299,22 @@ function show_aborted($all_batches, $limit, $user, $app) {
             $batch->app_name,
             $batch->njobs,
             local_time_str($batch->create_time),
-            local_time_str($batch->completion_time)
+            local_time_str($batch->completion_time),
+            sprintf('<input type=checkbox name=retire_%d>', $batch->id)
         );
     }
     if (!$first) {
         end_table();
+        form_submit('Retire selected batches');
         form_end();
     }
 }
 
 // fill in the app and user names in list of batches
-// TODO: speed this up by making list of app and user IDs
-// and doing lookup just once.
 //
 function fill_in_app_and_user_names(&$batches) {
     $apps = [];
+    $users = [];
     foreach ($batches as $batch) {
         if (array_key_exists($batch->app_id, $apps)) {
             $app = $apps[$batch->app_id];
@@ -292,12 +325,18 @@ function fill_in_app_and_user_names(&$batches) {
         if ($app) {
             $batch->app_name = $app->name;
             if ($batch->description) {
-                $batch->app_name .= ": $batch->description";
+                $batch->app_name .= " ($batch->description)";
             }
         } else {
             $batch->app_name = "unknown";
         }
-        $user = BoincUser::lookup_id($batch->user_id);
+
+        if (array_key_exists($batch->user_id, $users)) {
+            $user = $users[$batch->user_id];
+        } else {
+            $user = BoincUser::lookup_id($batch->user_id);
+            $users[$batch->user_id] = $user;
+        }
         if ($user) {
             $batch->user_name = $user->name;
         } else {
@@ -306,19 +345,19 @@ function fill_in_app_and_user_names(&$batches) {
     }
 }
 
-// show a set of batches
+// show a set of batches: in progress, then completed, then aborted
 //
-function show_batches($batches, $limit, $user, $app) {
+function show_batches($batches, $order, $limit, $user, $app) {
     fill_in_app_and_user_names($batches);
     $batches = get_batches_params($batches);
-    show_in_progress($batches, $limit, $user, $app);
-    show_complete($batches, $limit, $user, $app);
-    show_aborted($batches, $limit, $user, $app);
+    show_in_progress($batches, $order, $limit, $user, $app);
+    show_complete($batches, $order, $limit, $user, $app);
+    show_aborted($batches, $order, $limit, $user, $app);
 }
 
 // show links to per-app job submission forms
 //
-function handle_main($user) {
+function show_submit_links($user) {
     global $remote_apps;
     $user_submit = BoincUserSubmit::lookup_userid($user->id);
     if (!$user_submit) {
@@ -342,7 +381,7 @@ function handle_main($user) {
                         );
                     } else {
                         echo sprintf(
-                            '<li><a href=%s>%s</a><p>',
+                            '<a href=%s>%s</a><p>',
                             $app->form, $app->long_name
                         );
                     }
@@ -357,7 +396,7 @@ function handle_main($user) {
         'Jobs you submit can run', 'only_own',
         [
             [0, 'on any computer'],
-            [1, 'only on your computers']
+            [1, 'only on your computers (and no other jobs will run there)']
         ],
         $user->seti_id
     );
@@ -369,20 +408,32 @@ function handle_main($user) {
 // show batches of logged in user.
 // They have manage access to these batches.
 //
-function handle_show_status($user) {
-    page_head("Batches");
+function handle_show_user_batches($user) {
+    page_head("Your batches");
     $order = get_order();
-    order_options('action=status', $order);
-    $clause = order_clause($order);
-    $batches = BoincBatch::enum("user_id = $user->id order by $clause");
-    get_batches_params($batches);
-    show_batches($batches, PAGE_SIZE, $user, null);
+    order_options('action=show_user_batches', $order);
+    $batches = BoincBatch::enum("user_id = $user->id");
+    show_batches($batches, $order, PAGE_SIZE, $user, null);
 
     page_tail();
 }
 
 function handle_update_only_own($user) {
+    if (!parse_bool(get_config(), 'enable_assignment')) {
+        error_page(
+            'Job assignment is not enabled in the project config file.
+            Please ask the project admins to enable it.'
+        );
+        return;
+    }
     $val = get_int('only_own');
+    if ($val) {
+        if (BoincHost::count("userid=$user->id") == 0) {
+            error_page(
+                "You don't have any computers running BOINC and attached to this project."
+            );
+        }
+    }
     $user->update("seti_id=$val");
     header("Location: submit.php");
 }
@@ -409,6 +460,7 @@ function handle_admin($user) {
         // user can administer all apps
         //
         page_head("Job submission: manage all apps");
+        echo '<ul>';
         echo "<li> <a href=submit.php?action=admin_all>View/manage all batches</a>
         ";
         $app_names = get_remote_app_names();
@@ -418,7 +470,7 @@ function handle_admin($user) {
             echo "
                 <li>$app->user_friendly_name<br>
                 <ul>
-                <li><a href=submit.php?action=admin_app&app_id=$app->id>View/manage batches</a>
+                <li><a href=submit.php?action=show_batches_admin_app&app_id=$app->id>View/manage batches</a>
             ";
             if ($app_name == 'buda') {
                 echo "
@@ -437,11 +489,12 @@ function handle_admin($user) {
         // see if user can administer specific apps
         //
         page_head("Job submission: manage apps");
+        echo '<ul>';
         $usas = BoincUserSubmitApp::enum("user_id=$user->id");
         foreach ($usas as $usa) {
             $app = BoincApp::lookup_id($usa->app_id);
             echo "<li>$app->user_friendly_name<br>
-                <a href=submit.php?action=admin_app&app_id=$app->id>Batches</a>
+                <a href=submit.php?action=show_batches_admin_app&app_id=$app->id>Batches</a>
             ";
             if ($usa->manage) {
                 echo "&middot;
@@ -454,7 +507,9 @@ function handle_admin($user) {
     page_tail();
 }
 
-function handle_admin_app($user) {
+// show all batches for given app to administrator
+//
+function show_batches_admin_app($user) {
     $app_id = get_int("app_id");
     $app = BoincApp::lookup_id($app_id);
     if (!$app) error_page("no such app");
@@ -463,22 +518,20 @@ function handle_admin_app($user) {
     }
 
     $order = get_order();
-    $clause = order_clause($order);
 
     page_head("Manage batches for $app->user_friendly_name");
-    order_options("action=admin_app&app_id=$app_id", $order);
-    $batches = BoincBatch::enum("app_id = $app_id order by $clause");
-    show_batches($batches, PAGE_SIZE, null, $app);
+    order_options("action=show_batches_admin_app&app_id=$app_id", $order);
+    $batches = BoincBatch::enum("app_id = $app_id");
+    show_batches($batches, $order, PAGE_SIZE, null, $app);
     page_tail();
 }
 
 function handle_admin_all($user) {
     $order = get_order();
-    $clause = order_clause($order);
-    page_head("Administer batches (all apps)");
+    page_head("Administer batches (all apps and users)");
     order_options("action=admin_all", $order);
-    $batches = BoincBatch::enum("true order by $clause");
-    show_batches($batches, PAGE_SIZE, null, null);
+    $batches = BoincBatch::enum('');
+    show_batches($batches, $order, PAGE_SIZE, null, null);
     page_tail();
 }
 
@@ -591,7 +644,9 @@ function progress_bar($batch, $wus, $width) {
 //
 function handle_query_batch($user) {
     $batch_id = get_int('batch_id');
+    $status = get_int('status', true);
     $batch = BoincBatch::lookup_id($batch_id);
+    if (!$batch) error_page('no batch');
     $app = BoincApp::lookup_id($batch->app_id);
     $wus = BoincWorkunit::enum_fields(
         'id, name, rsc_fpops_est, canonical_credit, canonical_resultid, error_mask',
@@ -609,26 +664,29 @@ function handle_query_batch($user) {
     page_head("Batch $batch_id");
     text_start(800);
     start_table();
-    row2("name", $batch->name);
+    row2("Batch name", $batch->name);
     if ($batch->description) {
-        row2('description', $batch->description);
+        row2('Description', $batch->description);
     }
     if ($owner) {
-        row2('submitter', $owner->name);
+        row2('Submitter',
+            "<a href=show_user.php?userid=$owner->id>$owner->name</a>"
+        );
     }
-    row2("application", $app?$app->name:'---');
-    row2("state", batch_state_string($batch->state));
+    row2("Submitted", time_str($batch->create_time));
+    row2("Application", $app?$app->name:'---');
+    row2("State", batch_state_string($batch->state));
     //row2("# jobs", $batch->njobs);
     //row2("# error jobs", $batch->nerror_jobs);
     //row2("logical end time", time_str($batch->logical_end_time));
     if ($batch->expire_time) {
-        row2("expiration time", time_str($batch->expire_time));
+        row2("Expiration time", time_str($batch->expire_time));
     }
     if ($batch->njobs) {
-        row2("progress", progress_bar($batch, $wus, 600));
+        row2('Progress', progress_bar($batch, $wus, 600));
     }
     if ($batch->completion_time) {
-        row2("completed", local_time_str($batch->completion_time));
+        row2("Completed", local_time_str($batch->completion_time));
     }
     row2("GFLOP/hours, estimated", number_format(credit_to_gflop_hours($batch->credit_estimate), 2));
     row2("GFLOP/hours, actual", number_format(credit_to_gflop_hours($batch->credit_canonical), 2));
@@ -683,6 +741,22 @@ function handle_query_batch($user) {
     ";
 
     echo "<h2>Jobs</h2>\n";
+    $url = "submit.php?action=query_batch&batch_id=$batch_id";
+    echo "Show: ";
+    echo sprintf('
+        <a href=%s&status=%d>failed</a> &middot;
+        <a href=%s&status=%d>completed</a> &middot;
+        <a href=%s&status=%d>in progress</a> &middot;
+        <a href=%s&status=%d>unsent</a> &middot;
+        <a href=%s>all</a>
+        <p>',
+        $url, WU_ERROR,
+        $url, WU_SUCCESS,
+        $url, WU_IN_PROGRESS,
+        $url, WU_UNSENT,
+        $url
+    );
+
     start_table();
     $x = [
         "Name <br><small>click for details</small>",
@@ -691,6 +765,7 @@ function handle_query_batch($user) {
     ];
     row_heading_array($x);
     foreach($wus as $wu) {
+        if ($status && $wu->status != $status) continue;
         $y = '';
         $c = '---';
         switch($wu->status) {
@@ -754,9 +829,11 @@ function handle_query_job($user) {
     text_start(800);
 
     echo "
+        <ul>
         <li><a href=workunit.php?wuid=$wuid>Job details</a>
         <p>
         <li><a href=submit.php?action=query_batch&batch_id=$wu->batch>Batch details</a>
+        </ul>
     ";
     $d = "<foo>$wu->xml_doc</foo>";
     $x = simplexml_load_string($d);
@@ -773,31 +850,40 @@ function handle_query_job($user) {
     $results = BoincResult::enum("workunitid=$wuid");
     $upload_dir = parse_config(get_config(), "<upload_dir>");
     $fanout = parse_config(get_config(), "<uldl_dir_fanout>");
-    foreach($results as $result) {
+    foreach ($results as $result) {
         $x = [
             "<a href=result.php?resultid=$result->id>$result->id</a>",
             state_string($result)
         ];
-        $i = 0;
-        if ($result->server_state == RESULT_SERVER_STATE_OVER) {
-            $phys_names = get_outfile_phys_names($result);
-            $log_names = get_outfile_log_names($result);
-            for ($i=0; $i<count($phys_names); $i++) {
-                if ($is_assim_move) {
-                    // file is in
-                    // project/results/<batchid>/<wu_name>__file_<log_name>
-                    $path = sprintf('results/%s/%s__file_%s',
-                        $wu->batch, $wu->name, $log_names[$i]
-                    );
+        if ($is_assim_move) {
+            if ($result->id == $wu->canonical_resultid) {
+                $log_names = get_outfile_log_names($result);
+                $nfiles = count($log_names);
+                for ($i=0; $i<$nfiles; $i++) {
                     $name = $log_names[$i];
                     // don't show 'view' link if it's a .zip
                     $y = "$name: ";
                     if (!strstr($name, '.zip')) {
-                        $y .= "<a href=get_output3.php?action=get_file&path=$path>view</a> &middot; ";
+                        $y .= sprintf(
+                            '<a href=get_output3.php?action=get_file&result_id=%d&index=%d>view</a> &middot; ',
+                            $result->id, $i
+                        );
                     }
-                    $y .= "<a href=get_output3.php?action=get_file&path=$path&download=1>download</a>";
+                    $y .= sprintf(
+                        '<a href=get_output3.php?action=get_file&result_id=%d&index=%d&download=1>download</a>',
+                        $result->id, $i
+                    );
                     $x[] = $y;
-                } else {
+                }
+            } else {
+                $x[] = '---';
+            }
+        } else {
+            if ($result->server_state == RESULT_SERVER_STATE_OVER) {
+                $phys_names = get_outfile_phys_names($result);
+                $log_names = get_outfile_log_names($result);
+                $nfiles = count($log_names);
+                for ($i=0; $i<$nfiles; $i++) {
                     $path = dir_hier_path(
                         $phys_names[$i], $upload_dir, $fanout
                     );
@@ -817,9 +903,9 @@ function handle_query_job($user) {
                         $x[] = sprintf("file '%s' is missing", $log_names[$i]);
                     }
                 }
+            } else {
+                $x[] = '---';
             }
-        } else {
-            $x[] = '---';
         }
         row_array($x);
     }
@@ -830,23 +916,27 @@ function handle_query_job($user) {
     echo "<h2>Input files</h2>\n";
     $x = "<in>".$wu->xml_doc."</in>";
     $x = simplexml_load_string($x);
-    start_table('table-striped');
-    table_header("Name<br><small>(click to view)</small>", "Size (bytes)");
-    foreach ($x->workunit->file_ref as $fr) {
-        $pname = (string)$fr->file_name;
-        $lname = (string)$fr->open_name;
-        foreach ($x->file_info as $fi) {
-            if ((string)$fi->name == $pname) {
-                table_row(
-                    "<a href=$fi->url>$lname</a>",
-                    $fi->nbytes
-                );
-                break;
+    if ($x->workunit->file_ref) {
+        start_table('table-striped');
+        table_header("Name<br><small>(click to view)</small>", "Size (bytes)");
+        foreach ($x->workunit->file_ref as $fr) {
+            $pname = (string)$fr->file_name;
+            $lname = (string)$fr->open_name;
+            foreach ($x->file_info as $fi) {
+                if ((string)$fi->name == $pname) {
+                    table_row(
+                        "<a href=$fi->url>$lname</a>",
+                        $fi->nbytes
+                    );
+                    break;
+                }
             }
         }
+        end_table();
+    } else {
+        echo "The job has no input files.<p>";
     }
 
-    end_table();
     text_end();
     return_link();
     page_tail();
@@ -873,12 +963,13 @@ function handle_abort_batch($user) {
 
     if (get_int('confirmed', true)) {
         abort_batch($batch);
-        page_head("Batch aborted");
+        page_head("Batch $batch_id aborted");
         return_link();
         page_tail();
     } else {
         page_head("Confirm abort batch");
         echo "
+            <p>
             Aborting a batch will cancel all unstarted jobs.
             Are you sure you want to do this?
             <p>
@@ -925,7 +1016,7 @@ function handle_retire_batch($user) {
 //
 function handle_retire_multi($user) {
     $batches = BoincBatch::enum(
-        sprintf('state=%d', BATCH_STATE_COMPLETE)
+        sprintf('state in (%d, %d)', BATCH_STATE_COMPLETE, BATCH_STATE_ABORTED)
     );
     page_head('Retiring batches');
     foreach ($batches as $batch) {
@@ -949,35 +1040,36 @@ function show_batches_in_state($batches, $state, $url_args, $order) {
     case BATCH_STATE_IN_PROGRESS:
         page_head("Batches in progress");
         order_options($url_args, $order);
-        show_in_progress($batches, 0, null, null);
+        show_in_progress($batches, $order, 0, null, null);
         break;
     case BATCH_STATE_COMPLETE:
         page_head("Completed batches");
         order_options($url_args, $order);
-        show_complete($batches, 0, null, null);
+        show_complete($batches, $order, 0, null, null);
         break;
     case BATCH_STATE_ABORTED:
         page_head("Aborted batches");
         order_options($url_args, $order);
-        show_aborted($batches, 0, null, null);
+        show_aborted($batches, $order, 0, null, null);
         break;
     }
     page_tail();
 }
 
-function handle_show_all($user) {
+// show all batches visible to user, possibly limited by user/app/state
+function handle_show_all_batches($user) {
     $userid = get_int("userid");
     $appid = get_int("appid");
     $state = get_int("state");
     $order = get_order();
-    $url_args = "action=show_all&state=$state&userid=$userid&appid=$appid";
-    $clause = order_clause($order);
+    $url_args = "action=show_all_batches&state=$state&userid=$userid&appid=$appid";
     if ($userid) {
         // user looking at their own batches
         //
         if ($userid != $user->id) error_page("wrong user");
-        $batches = BoincBatch::enum("user_id=$user->id and state=$state order by $clause");
+        $batches = BoincBatch::enum("user_id=$user->id and state=$state");
         fill_in_app_and_user_names($batches);
+        $batches = get_batches_params($batches);
         show_batches_in_state($batches, $state, $url_args, $order);
     } else {
         // admin looking at batches
@@ -988,11 +1080,12 @@ function handle_show_all($user) {
         if ($appid) {
             $app = BoincApp::lookup_id($appid);
             if (!$app) error_page("no such app");
-            $batches = BoincBatch::enum("app_id=$appid and state=$state order by $clause");
+            $batches = BoincBatch::enum("app_id=$appid and state=$state");
         } else {
-            $batches = BoincBatch::enum("state=$state order by $clause");
+            $batches = BoincBatch::enum("state=$state");
         }
         fill_in_app_and_user_names($batches);
+        $batches = get_batches_params($batches);
         show_batches_in_state($batches, $state, $url_args, $order);
     }
 }
@@ -1002,19 +1095,32 @@ $user = get_logged_in_user();
 $action = get_str('action', true);
 
 switch ($action) {
-case '': handle_main($user); break;
-case 'abort_batch': handle_abort_batch($user); break;
-case 'admin': handle_admin($user); break;
-case 'admin_app': handle_admin_app($user); break;
+
+// links to job submission forms
+case '': show_submit_links($user); break;
+
+// show lists of batches
+case 'show_all_batches': handle_show_all_batches($user); break;
+case 'show_user_batches': handle_show_user_batches($user); break;
+case 'show_batches_admin_app': show_batches_admin_app($user); break;
 case 'admin_all': handle_admin_all($user); break;
+
+// show info about a batch or job
 case 'batch_stats': handle_batch_stats($user); break;
 case 'query_batch': handle_query_batch($user); break;
 case 'query_job': handle_query_job($user); break;
+
+// operations on batches
 case 'retire_batch': handle_retire_batch($user); break;
 case 'retire_multi': handle_retire_multi($user); break;
-case 'show_all': handle_show_all($user); break;
-case 'status': handle_show_status($user); break;
+case 'abort_batch': handle_abort_batch($user); break;
+
+// access control
+case 'admin': handle_admin($user); break;
+
+// 'run jobs only on my computers' flag (stored in user.seti_id)
 case 'update_only_own': handle_update_only_own($user); break;
+
 default:
     error_page("no such action $action");
 }
