@@ -180,7 +180,8 @@ enum SUSPEND_REASON {
     SUSPEND_REASON_WIFI_STATE = 4097,
     SUSPEND_REASON_BATTERY_CHARGING = 4098,
     SUSPEND_REASON_BATTERY_OVERHEATED = 4099,
-    SUSPEND_REASON_NO_GUI_KEEPALIVE = 4100
+    SUSPEND_REASON_NO_GUI_KEEPALIVE = 4100,
+    SUSPEND_REASON_PODMAN_INIT = 4101
 };
 
 // battery state (currently used only for Android)
